@@ -1,8 +1,8 @@
 context("maxLikelihood.Guilds")
 
 test_that("maxLikelihood.Guilds: use", {
-#  skip_on_cran() # takes too long
- # testthat::skip("takes too long")
+  skip_on_cran() # takes too long
+  testthat::skip("takes too long")
   set.seed(42)
   J <- 1000
 
